Home - Bibliographica

# Bibliographica

# Terms and Conditions

Bibliographica contains data from various sources. Where particular providers of data have requested that their terms and conditions be displayed, they are reproduced below.

Where data is not explicitly marked as being covered by a different policy, the terms of the general OKFN IP policy apply.

- British Library

## British Library

Use of Data: This data is being made available under a Creative Commons CC0 1.0 Universal Public Domain Dedication licence. This means that the British Library Board makes no copyright, related or neighbouring rights claims to the data and does not apply any restrictions on subsequent use and reuse of the data. The British Library accepts no liability for damages from any use of the supplied data. For more detail please see the terms of the licence.

Support: The British Library is committed to providing high quality services and accurate data. If you have any queries or identify any problems with the data please contact metadata@bl.uk

Share knowledge: We are also very interested to hear the ways in which you have used this data so we can understand more fully the benefits of sharing it and improve our services. Please contact metadata@bl.uk if you wish to share your experiences with us and those that are using this service.

Give Credit Where Credit is Due: The British Library has a responsibility to maintain its bibliographic data on the nation's behalf. Please credit all use of this data to the British Library and link back to www.bl.uk/bibliographic/datafree.html in order that this information can be shared and developed with today's Internet users as well as future generations.

> NOTE: British Library data from the British National Bibliography is identified by URIs that begin with `http://bnb.bibliographica.org/`.

- ### About

  The Bibliographica service is an open catalogue of cultural works. Find out more ».